package com.playlet.system.mapper;

import java.util.List;
import com.playlet.system.domain.PlayletBanner;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 短剧广告管理Mapper接口
 *
 * @author ruoyi
 * @date 2024-03-10
 */
public interface PlayletBannerMapper extends BaseMapper<PlayletBanner>
{
    /**
     * 查询短剧广告管理
     *
     * @param id 短剧广告管理主键
     * @return 短剧广告管理
     */
    public PlayletBanner selectPlayletBannerById(Long id);

    /**
     * 查询短剧广告管理列表
     *
     * @param playletBanner 短剧广告管理
     * @return 短剧广告管理集合
     */
    public List<PlayletBanner> selectPlayletBannerList(PlayletBanner playletBanner);

    /**
     * 新增短剧广告管理
     *
     * @param playletBanner 短剧广告管理
     * @return 结果
     */
    public int insertPlayletBanner(PlayletBanner playletBanner);

    /**
     * 修改短剧广告管理
     *
     * @param playletBanner 短剧广告管理
     * @return 结果
     */
    public int updatePlayletBanner(PlayletBanner playletBanner);

    /**
     * 删除短剧广告管理
     *
     * @param id 短剧广告管理主键
     * @return 结果
     */
    public int deletePlayletBannerById(Long id);

    /**
     * 批量删除短剧广告管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlayletBannerByIds(String[] ids);
}
